<?php

require_once 'classes/Base.php';

abstract class ActiveRecord {

	private $attrs;
	private $keys;
	private $nouveau;
	private $table;

	public function __construct($attr_names, $keys, $attr_values, $nouveau) {
		$this->keys = $keys;
		$this->nouveau = $nouveau;
		$this->table = strtolower(get_class($this));
		$this->attrs = array();

		// Merci Oracle
		foreach($attr_values as $k => $v)
			$attr_values[strtolower($k)] = $v;

		foreach($attr_names as $attr_name)
			$this->attrs[$attr_name] = array_key_exists($attr_name, $attr_values) ?  $attr_values[$attr_name] : null;
	}
	
	public function __get($attr){
		if(!array_key_exists($attr, $this->attrs)) {
			$emess = __CLASS__ . " : unknown member $attr (__get)";
			throw new Exception($emess, 45);
		}

		if(strpos($attr, 'date_') !== false)
			return date('Y-m-d H:i:s', $this->attrs[$attr]);

		return $this->attrs[$attr];
	}

	public function __set($attr_name, $value) {
		if(strpos($attr_name, 'date_') !== false)
			$value = strtotime($value);

		$this->attrs[$attr_name] = addslashes($value);

		return $value;
	}

	public function save() {
		return $this->nouveau ? $this->insert() : $this->update();
	}

	private function update() {
		$save_query = "UPDATE $this->table SET ";

		$i = 0;
		foreach($this->attrs AS $attr => $valeur) {
			if($i > 0)
				$save_query .= ", ";
			$save_query .= "$attr=".(empty($valeur) ? "NULL" : "'$valeur'").' ';
			$i++;
		}

		$save_query .= "WHERE ";

		$i = 0;
		foreach($this->keys AS $key) {
			if ($i > 0)
				$save_query .= "AND ";
			$save_query .= "$key='".$this->attrs[$key]."' ";
			$i++;
		}

		$save_query = preg_replace("/'(\d+)'/", '\1', $save_query);

		$conn = Base::getConnection();
		$query = $conn->prepare($save_query);
		$query->execute(); // or die(print_r($conn->errorInfo(), true));
	}

	public function insert() {
		$insert_query = sprintf(
			'INSERT INTO %s(%s) VALUES(%s)',
			$this->table,
			implode(', ', array_keys($this->attrs)),
			"'".implode("', '", array_values($this->attrs))."'"
		);

		$insert_query = preg_replace("/'\s*'/", "NULL", $insert_query);
		$insert_query = preg_replace("/'(\d+)'/", '\1', $insert_query);

		$conn = Base::getConnection();
		$query = $conn->exec($insert_query) or die(print_r($conn->errorInfo(), true));

		$this->nouveau = false;
	}

	public function lastInsertId() {
		require_once 'classes/config.php';

		$conn = Base::getConnection();

		if(SGBD == 'mysql')
			return $conn->lastInsertId();
		else {
			$select_query = "SELECT inc_{$this->table}_seq.CURRVAL FROM DUAL";

			$query = $conn->prepare($select_query);
			$query->execute();

			$result = $query->fetch(PDO::FETCH_NUM);

			return $result[0];
		}
	}

	public function delete() {
		if(empty($this->keys))
			throw new Exception(__CLASS__ . ": Primary Key undefined : cannot update");

		$save_query = "DELETE FROM $this->table WHERE ";

		$i = 0;
		foreach($this->keys AS $key) {
			if ($i > 0)
				$save_query .= "AND ";
			$save_query .= "$key='".$this->attrs[$key]."' ";
			$i++;
		}

		$save_query = preg_replace("/'(\d+)'/", '\1', $save_query);

		$conn = Base::getConnection();
		$query = $conn->prepare($save_query);
		$query->execute();
	}
	
	public static function findAll() {
		$table = strtolower(get_called_class());

		$select_query = "SELECT * FROM $table";

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$count = $query->execute();
		
		$values = array();

		while($result = $query->fetch(PDO::FETCH_ASSOC)) {
			$v = new $table($result, false);
			$values[] = $v;
		}

		return $values;
	}

	public static function findById($keys) {
		$table = strtolower(get_called_class());

		$select_query = "SELECT * FROM $table WHERE ";

		$i = 0;
		foreach($keys AS $key => $valeur) {
			if($i > 0)
				$select_query .= "AND ";
			$select_query .= "$key='".$valeur."' ";
			$i++;
		}

		$select_query = preg_replace("/'(\d+)'/", '\1', $select_query);

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$query->execute();

		$result = $query->fetch(PDO::FETCH_ASSOC);

		if(!empty($result))
			$value = new $table($result, false);
		else
			$value = null;

		return $value;
	}
}

?>
