<?php

require_once 'classes/Base.php';
require_once 'classes/ActiveRecord.php';

class Evenement extends ActiveRecord {
	public function __construct($attrs, $nouveau = false) {
		parent::__construct(
		// Attributs
		array(
			'id',
			'id_recurrence',
			'id_agenda',
			'nom',
			'descr',
			'lieu',
			'date_deb',
			'date_fin',
			'est_public',
			'exclusif',
			'rappel'
		),

		// Attributs de clef
		array('id'),

		// Valeurs
		$attrs, $nouveau
		);
	}

	public function insert() {
		parent::insert();
		$this->id = parent::lastInsertId();
	}

	public static function findByAgenda($id_agenda) {
		$select_query = "SELECT * FROM evenement WHERE id_agenda='$id_agenda'";

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$query->execute();

		$evts = array();
		while($result = $query->fetch(PDO::FETCH_ASSOC)) {
			$evts[] = new Evenement($result, false);
		}
		return $evts;
	}
	
	public static function findByIdRec($id) {
		$select_query = "SELECT * FROM evenement WHERE id_recurrence=$id";

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$query->execute();

		$evts = array();
		while($result = $query->fetch(PDO::FETCH_ASSOC)) {
			$evts[] = new Evenement($result, false);
		}

		return $evts;
	}

    public static function findExclusif($login, $date_deb, $date_fin) {
        $select_query = "SELECT e.id FROM evenement e, association_agenda aa
            WHERE e.exclusif = 1
            AND e.date_deb <= $date_fin
            AND e.date_fin >= $date_deb
            AND aa.login = '$login'
            AND aa.id = e.id_agenda";

        $conn = Base::getConnection();
        $query = $conn->prepare($select_query);
        $query->execute();

        $evts = array();
        while($result = $query->fetch(PDO::FETCH_ASSOC)) {
            $evts[]= Evenement::findById(array('id' => $result['ID']));
        }

        return $evts;
    }

	/**
	 * Teste si l'utilisateur a accès à l'événement
	 * @param unknown_type $login
	 */
	public function droitsUtilisateur($login=null) {
		require_once 'classes/Agenda.php';
		$agenda = Agenda::findById(array("id" => $this->id_agenda));
		if($agenda->est_public && $this->est_public)
			return true;
		else if($login == null)
			return false;

		require_once 'identification.php'; // ou pas
		require_once 'classes/Association_Agenda.php';
		$asso_util_agenda = Association_Agenda::findById(array("login" => $login, "id" => $this->id_agenda));
		// tester si l'agenda appartient à l'utilisateur
		if(isset($asso_util_agenda))
			$autorise = true;
		else {
			// tester si l'agenda est partagé à l'utilisateur
			require_once 'classes/Partage.php';
			$partage = Partage::findById(array("login" => $login, "id_agenda" => $this->id_agenda));
			if(isset($partage))
				$autorise = true;
		}
		return $autorise;
	}
	
	public function delete() {
		parent::delete();
		
		require_once 'classes/Invitation.php';
		require_once 'classes/Association_Ressource.php';
		
		// supprimer les invitations liées à l'évènement
		$invitations = Invitation::findByEvenement($this->id);
		
		foreach($invitations as $i) {
			$i->delete();
		}
		
		// supprimer les associations avec les ressources
		$asso_ress = Association_Ressource::findByEvenement($this->id);
		
		foreach($asso_ress as $ar) {
			$ar->delete();
		}
		
		// supprimer les événements récurrents liés
		$rec = Evenement::findByIdRec($this->id);
		
		foreach($rec as $evt) {
			$evt->delete();
		}
	}
	
	public function creerRecurrence($intervale) {
		$durees_acceptees = array('h' => 'hour', 'j' => 'day', 'm' => 'month', 'a' => 'year');
		$duree = $intervale[strlen($intervale) - 1];
		$qte = intval($intervale);

		if(!in_array($duree, array_keys($durees_acceptees))) {
			require_once 'vues/VueErreurCreerEvenementDate.php';
			new VueErreurCreerEvenementDate();
			return;
		}

		try {
			$date_deb = new DateTime($this->date_deb);
			$date_fin = new DateTime($this->date_fin);
			$recurrence = DateInterval::createFromDateString($qte . " " . $durees_acceptees[$duree]);
		
			$date_max = new DateTime('01-01-2050');
			$date_deb_rec = new DatePeriod($date_deb, $recurrence, $date_max);
			$date_fin_rec = new DatePeriod($date_fin, $recurrence, $date_max);

			$i = 0;
			foreach($date_deb_rec AS $date)
				$dates_deb_fin[$i++][0] = $date->format('Y-m-d H:i:s');
		
			$j = 0;
			foreach($date_fin_rec AS $date)
				$dates_deb_fin[$j++][1] = $date->format('Y-m-d H:i:s');
		
			for($k = 1; $k < ($i < $j ? $i : $j); $k++) {
				$evt = new Evenement(array(
					'nom' => $this->nom,
					'id_recurrence' => $this->id,
					'id_agenda' => $this->id_agenda,
					'descr' => $this->descr,
					'lieu' => $this->lieu,
					'date_deb' => $dates_deb_fin[$k][0],
					'date_fin' => $dates_deb_fin[$k][1],
					'est_public' => $this->est_public,
					'exclusif' => $this->exclusif,
					'rappel' => $this->rappel),
				true);
				$evt->save();
			}
		
		} catch(Exception $e) {
			echo $e->getMessage();
		}	
	}

	public function supprimerRecurrence() {
		$select_query = "DELETE FROM evenement WHERE id_recurrence=$this->id";

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$query->execute();
	}

	public function est_recurrent() {
		if($this->id_recurrence != null)
			return true;

		$select_query = "SELECT COUNT(*) FROM evenement WHERE id_recurrence=$this->id";

		$conn = Base::getConnection();
		$query = $conn->prepare($select_query);
		$query->execute();

		return $query->fetchColumn() > 0;
	}

	public function propager_recurrence() {
		$rec = Evenement::findByIdRec($this->id);

		foreach($rec as $evt) {
			$evt->id_agenda = $this->id_agenda;
			$evt->nom = $this->nom;
			$evt->descr = $this->descr;
			$evt->lieu = $this->lieu;
			$evt->est_public = $this->est_public;
			$evt->exclusif = $this->exclusif;
			$evt->rappel = $this->rappel;
			$evt->save();
		}

	}
}

?>
