<?php

/**
 * Fichier contrôleur de gestion des événements
 */

session_start();

require_once 'classes/Evenement.php';

switch($_GET['action']) {
case "creer" :
    creerEvenement();
    break;

case "inviter" :
    inviterEvenement();
    break;

case "consulter" :
    consulterEvenement();
    break;

case "accepter" :
    accepterInvitation();
    break;

case "modifier" :
    modifierEvenement();
    break;

case "supprimer" :
    supprimerEvenement();
    break;
}

/*
 * OPÉRATION S4 et S6
 * Ajouter un nouvel événement (partagé ou non) dans le système
 */

function creerEvenement(){
    require_once 'identification.php';
    require_once 'classes/Agenda.php';

    if(!empty($_POST['id_agenda']) && !empty($_POST['nom']) && !empty($_POST['date_deb']) && !empty($_POST['date_fin'])
        && isset($_POST['est_public']) && isset($_POST['exclusif'])) {

            // vérifier que l'utilisateur a les droits sur l'agenda
            $agenda = Agenda::findById(array('id' => $_POST['id_agenda']));
            if($agenda->droitsUtilisateur($_SESSION['login']) > 5) {

                $nom = $_POST['nom'];
                $id_agenda = $_POST['id_agenda'];
                $descr = $_POST['desc'];
                $lieu = $_POST['lieu'];
                $date_deb = strtotime($_POST['date_deb']);
                $date_fin = strtotime($_POST['date_fin']);
                $est_public = $_POST['est_public'];
                $exclusif = $_POST['exclusif'];
                $rappel = $_POST['rappel'];

                // vérifier que l'utilisateur n'a pas d'événement exclusif pendant cette période
                $evts_exclusifs = Evenement::findExclusif($_SESSION['login'], $date_deb, $date_fin);

                if(! sizeof($evts_exclusifs)) {

                    $evt = new Evenement(array(
                        'nom' => $nom,
                        'id_recurrence' => null,
                        'id_agenda' => $id_agenda,
                        'descr' => $descr,
                        'lieu' => $lieu,
                        'date_deb' => $date_deb,
                        'date_fin' => $date_fin,
                        'est_public' => $est_public,
                        'exclusif' => $exclusif,
                        'rappel' => intval($rappel) > 0 ? intval($rappel) * 60 : null),
                    true);

                    $evt->save();

                    // vérifier si l'événement est associé à une ressource
                    if( !empty($_POST['ressource'])) {
                    require_once 'classes/Association_Ressource.php';
                    $asso_ressource = new Association_Ressource(array(
                        'id_ressource' => $_POST['ressource'],
                        'id_evenement' => $evt->id),
                    true);
                    $asso_ressource->save();

                }

                // vérifier si l'événement est récurrent
                if(!empty($_POST['recurrence'])) {
                    $evt->creerRecurrence($_POST['recurrence']);
                }

                // TODO: Entree at ou cron pour le rappel

                require_once 'vues/VueSuccesCreerEvenement.php';
                new VueSuccesCreerEvenement();

                } else {
                    require_once 'vues/VueErreurEvenementExclusif.php';
                    new VueErreurEvenementExclusif($date_deb, $date_fin, $evts_exclusifs);

                }

            } else {
                require_once 'vues/VueErreurDroits.php';
                new VueErreurDroits();
            }

        } else {
            // vérifier que l'utilisateur a les droits sur l'agenda
            $agenda = Agenda::findById(array('id' => $_GET['id_agenda']));
            if($agenda->droitsUtilisateur($_SESSION['login']) > 5) {

                require_once 'classes/Ressource.php';
                $ressources = Ressource::findAll();

                require_once 'vues/VueFormCreerEvenement.php';
                new VueFormCreerEvenement(intval($_GET['id_agenda']), $ressources);
            } else {
                require_once 'vues/VueErreurDroits.php';
                new VueErreurDroits();
            }

            return false;
        }
    return true;
}

/*
 * OPÉRATION S13
 * Consulter les détails d'un événement
 */
function consulterEvenement() {
    if(!empty($_REQUEST['id'])) {
        $id = $_REQUEST['id'];

        $evenement = Evenement::findById(array('id' => $id));

        if(!is_null($evenement)) {
            if($evenement->est_public || $evenement->droitsUtilisateur($_SESSION['login'])) {
                require_once 'classes/Ressource.php';
                $ressources = Ressource::findByEvenement($id);

                require_once 'vues/VueConsulterEvenement.php';
                new VueConsulterEvenement($evenement, $ressources);
            } else {
                require_once 'vues/VueErreurDroits.php';
                new VueErreurDroits();
            }
        } else {
            require_once 'vues/VueErreurEvenementID.php';
            new VueErreurEvenementID();
        }
    } else {
        require_once 'vues/VueErreurEvenementID.php';
        new VueErreurEvenementID();
    }
}

/*
 * OPÉRATION S11
 * Inviter un utilisateur à participer à un évènement
 */

function inviterEvenement() {
    require_once 'identification.php';
    if(!empty($_POST['id'])) {
	$id = $_POST['id'];
	$login = $_POST['login'];

	require_once 'classes/Utilisateur.php';

	if(Utilisateur::existe($login)) {
	    require_once 'classes/Agenda.php';
	    require_once 'classes/Invitation.php';
	    $evt = Evenement::findById(array('id' => $id));
	    $agenda = Agenda::findById(array('id' => $evt->id_agenda));

	    if($evt->droitsUtilisateur($_SESSION['login'])) {
		$invitation = new Invitation(array(
		    'login' => $login,
		    'id_evenement' =>$evt->id,
		    'participera' => 0),
		true);
		$invitation->save();

		// envoyer un mail d'invitation
		$sujet = "Invitation sur Ajuda";
		$message = "Bonjour,\n\nVous avez été invité à un événement par " . $_SESSION['login'] . ".\n";
		$message .= "Accédez à http://neptune.esial.uhp-nancy.fr/~vaubo0051/evenement.php?action=accepter&id_evenement=" . $id . " pour consulter l'événement. Vous pourrez également indiquer si vous participerez à l'événement.";
		$headers = "From: Ajuda <webmaster@ajuda.cesi>" . "\r\n";
		$headers.= "Reply-To: webmaster@ajuda.cesi";
		mail($login, $sujet, $message, $headers);


		require_once 'vues/VueSuccesInviterEvenement.php';
		new VueSuccesInviterEvenement();
	    } else {
		require_once 'vues/VueErreurDroits.php';
		new VueErreurDroits();
	    }

	} else {
	    require_once 'vues/VueErreurUtilisateurInexistant.php';
	    new VueErreurUtilisateurInexistant();
	}
    } else {
	require_once 'vues/VueFormInviterEvenement.php';
	new VueFormInviterEvenement(intval($_GET['id']));
    }
}

/*
 * OPÉRATION S12
 * Accepter l'invitation d'un utilisateur
 */

function accepterInvitation() {
    require_once 'identification.php';
    require_once 'classes/Invitation.php';

    if(!empty($_GET['id_evenement'])) {
	$id_evenement = $_GET['id_evenement'];

	$invit = Invitation::findById(array(
	    'id_evenement' => $id_evenement,
	    'login' => $_SESSION['login']));

	if(! is_null($invit)) {
	    if(!empty($_POST['participera'])) {
		$invit->participera = $_POST['participera'];
		$invit->save();

		require_once 'vues/VueSuccesAccepterInvitation.php';
		new VueSuccesAccepterInvitation();
	    } else {
		require_once 'vues/VueFormAccepterInvitation.php';
		new VueFormAccepterInvitation($id_evenement);
	    }
	} else {
	    require_once 'vues/VueErreurEvenementID.php';
	    new VueErreurEvenementID();
	}
    } else {
	require_once 'vues/VueErreurEvenementID.php';
	new VueErreurEvenementID();
    }
}

/*
 * OPÉRATIONS DE GESTION, non comprises dans la descr lexicale
 */

function modifierEvenement() {
    require_once 'identification.php';

    if(!empty($_POST['id']) && !empty($_POST['nom']) && !empty($_POST['date_deb']) && !empty($_POST['date_fin']) && isset($_POST['est_public']) && isset($_POST['exclusif'])) {
	$id = $_POST['id'];
	$nom = $_POST['nom'];
	$recurrence = $_POST['recurrence'];
	$descr = $_POST['desc'];
	$lieu = $_POST['lieu'];
	$date_deb = $_POST['date_deb'];
	$date_fin = $_POST['date_fin'];
	$est_public = $_POST['est_public'];
	$exclusif = $_POST['exclusif'];
	$rappel = $_POST['rappel'];

	$evenement = Evenement::findById(array('id' => $id));

	if(!is_null($evenement->id_recurrence))
	    $evenement = Evenement::findById(array('id' => $evenement->id_recurrence));

	$evenement->nom = $nom;
	$evenement->descr = $descr;
	$evenement->lieu = $lieu;
	$evenement->date_deb = $date_deb;
	$evenement->date_fin = $date_fin;
	$evenement->est_public = $est_public;
	$evenement->exclusif = $exclusif;
	$evenement ->rappel = intval($rappel) < 1 ? null : intval($rappel) * 60;
	$evenement->save();

	// TODO: Modifier at ou cron pour le rappel

	if(!empty($recurrence)) {
	    $evenement->supprimerRecurrence();
	    $evenement->creerRecurrence($recurrence);
	} else 
	    $evenement->propager_recurrence();

	require_once 'vues/VueSuccesModifEvenement.php';
	new VueSuccesModifEvenement();

    } else {
        if(!empty($_GET['id'])) {
            require_once 'classes/Ressource.php';
            $ressources = Ressource::findAll();

            $evenement = Evenement::findById(array('id' => $_GET['id']));
            require_once 'vues/VueFormModifierEvenement.php';
            new VueFormModifierEvenement($evenement, $ressources);

        } else {
            require_once 'vues/VueErreurModifEvenement.php';
            new VueErreurModifEvenement();
        }
    }
}

function supprimerEvenement() {
    require_once 'identification.php';
    if(!empty($_GET['id'])) {
	$id = $_GET['id'];
	require_once 'classes/Agenda.php';

	$evt = Evenement::findById(array('id' => $id));
	$agenda = Agenda::findById(array('id' => $evt->id_agenda));
	if($agenda->droitsUtilisateur($_SESSION['login']) == 7) {
	    $evt->delete();

	    require_once 'vues/VueSuccesSupEvenement.php';
	    new VueSuccesSupEvenement();
	} else {
	    require_once 'vues/VueErreurDroits.php';
	    new VueErreurDroits();
	}
    } else {
	require_once 'vues/VueErreurEvenementID.php';
	new VueErreurEvenementID();
    }
}

?>
