-- -----------------------------------------------------------------------------
--             gnration d'une base de donnes pour
--                      oracle version 9i
--                        (9/11/2011 11:00:26)
-- -----------------------------------------------------------------------------
--      nom de la base : ajuda
--      projet : ajuda
--      auteur : julien (guepin | vaubourg)
--      date de dernire modification : 9/11/2011 10:59:35
-- -----------------------------------------------------------------------------

drop table utilisateur cascade constraints;

drop table evenement cascade constraints;

drop table agenda cascade constraints;

drop table ressource cascade constraints;

drop table partage cascade constraints;

drop table association_ressource cascade constraints;

drop table association_agenda cascade constraints;

drop table invitation cascade constraints;

-- -----------------------------------------------------------------------------
--       creation de la base 
-- -----------------------------------------------------------------------------

create database ajuda;

-- -----------------------------------------------------------------------------
--       table : utilisateur
-- -----------------------------------------------------------------------------

create table utilisateur
   (
    login char(32)  not null,
    password char(32)  not null,
    nom char(32)  null,
    prenom char(32)  null
,   constraint pk_utilisateur primary key (login)  
   ) ;

-- -----------------------------------------------------------------------------
--       table : evenement
-- -----------------------------------------------------------------------------

create table evenement
   (
    id number(5)  not null,
    id_recurrence number(5)  null,
    id_agenda number(5)  not null,
    nom char(32)  not null,
    descr long  null,
    lieu varchar2(256)  null,
    date_deb number(100)  not null,
    date_fin number(15)  not null,
    est_public number(15)  not null,
    exclusif number(1)  not null,
    rappel number(10)  null
,   constraint pk_evenement primary key (id)  
   ) ;

-- -----------------------------------------------------------------------------
--       index de la table evenement
-- -----------------------------------------------------------------------------

create  index i_fk_evenement_evenement
     on evenement (id_recurrence asc)
    ;

create  index i_fk_evenement_agenda
     on evenement (id_agenda asc)
    ;

-- -----------------------------------------------------------------------------
--       table : agenda
-- -----------------------------------------------------------------------------

create table agenda
   (
    id number(5)  not null,
    nom char(32)  not null,
    descr long  null,
    est_public number(1)  not null,
    couleur char(6)  null,
    afficher number(1)  null
,   constraint pk_agenda primary key (id)  
   ) ;

-- -----------------------------------------------------------------------------
--       table : ressource
-- -----------------------------------------------------------------------------

create table ressource
   (
    id number(5)  not null,
    nom char(32)  not null,
    descr long  null
,   constraint pk_ressource primary key (id)  
   ) ;

-- -----------------------------------------------------------------------------
--       table : partage
-- -----------------------------------------------------------------------------

create table partage
   (
    login char(32)  not null,
    id_agenda number(5)  not null,
    droit number(2)  not null
,   constraint pk_partage primary key (login, id_agenda)  
   ) ;

-- -----------------------------------------------------------------------------
--       index de la table partage
-- -----------------------------------------------------------------------------

create  index i_fk_partage_utilisateur
     on partage (login asc)
    ;

create  index i_fk_partage_agenda
     on partage (id_agenda asc)
    ;

-- -----------------------------------------------------------------------------
--       table : association_ressource
-- -----------------------------------------------------------------------------

create table association_ressource
   (
    id_ressource number(5)  not null,
    id_evenement number(5)  not null
,   constraint pk_association_ressource primary key (id_ressource, id_evenement)  
   ) ;

-- -----------------------------------------------------------------------------
--       index de la table association_ressource
-- -----------------------------------------------------------------------------

create  index i_fk_association_ressource_res
     on association_ressource (id_ressource asc)
    ;

create  index i_fk_association_ressource_eve
     on association_ressource (id_evenement asc)
    ;

-- -----------------------------------------------------------------------------
--       table : association_agenda
-- -----------------------------------------------------------------------------

create table association_agenda
   (
    login char(32)  not null,
    id number(5)  not null
,   constraint pk_association_agenda primary key (login, id)  
   ) ;

-- -----------------------------------------------------------------------------
--       index de la table association_agenda
-- -----------------------------------------------------------------------------

create  index i_fk_association_agenda_utilis
     on association_agenda (login asc)
    ;

create  index i_fk_association_agenda_agenda
     on association_agenda (id asc)
    ;

-- -----------------------------------------------------------------------------
--       table : invitation
-- -----------------------------------------------------------------------------

create table invitation
   (
    id_evenement number(5)  not null,
    login char(32)  not null,
    participera number(1)  not null
,   constraint pk_invitation primary key (id_evenement, login)  
   ) ;

-- -----------------------------------------------------------------------------
--       index de la table invitation
-- -----------------------------------------------------------------------------

create  index i_fk_invitation_evenement
     on invitation (id_evenement asc)
    ;

create  index i_fk_invitation_utilisateur
     on invitation (login asc)
    ;


-- -----------------------------------------------------------------------------
--       creation des references de table
-- -----------------------------------------------------------------------------


alter table evenement add (
     constraint fk_evenement_evenement
          foreign key (id_recurrence)
               references evenement (id))   ;

alter table evenement add (
     constraint fk_evenement_agenda
          foreign key (id_agenda)
               references agenda (id))   ;

alter table partage add (
     constraint fk_partage_utilisateur
          foreign key (login)
               references utilisateur (login))   ;

alter table partage add (
     constraint fk_partage_agenda
          foreign key (id_agenda)
               references agenda (id))   ;

alter table association_ressource add (
     constraint fk_association_ressource_resso
          foreign key (id_ressource)
               references ressource (id))   ;

alter table association_ressource add (
     constraint fk_association_ressource_evene
          foreign key (id_evenement)
               references evenement (id))   ;

alter table association_agenda add (
     constraint fk_association_agenda_utilisat
          foreign key (login)
               references utilisateur (login))   ;

alter table association_agenda add (
     constraint fk_association_agenda_agenda
          foreign key (id)
               references agenda (id))   ;

alter table invitation add (
     constraint fk_invitation_evenement
          foreign key (id_evenement)
               references evenement (id))   ;

alter table invitation add (
     constraint fk_invitation_utilisateur
          foreign key (login)
               references utilisateur (login))   ;


-- -----------------------------------------------------------------------------
--                fin de generation
-- -----------------------------------------------------------------------------

-- -----------------------------------------------------------------------------
--       creation des triggers pour une alternative  AUTO_INCREMENT
-- -----------------------------------------------------------------------------

-- table evenement
create sequence inc_evenement_seq
start with 1
increment by 1
nomaxvalue;

create trigger inc_evenement_trigger
before insert on evenement
for each row
begin
select inc_evenement_seq.nextval into :new.id from dual;
end;
/

-- table agenda
create sequence inc_agenda_seq
start with 1
increment by 1
nomaxvalue;

create trigger inc_agenda_trigger
before insert on agenda
for each row
begin
select inc_agenda_seq.nextval into :new.id from dual;
end;
/

-- table ressource
create sequence inc_ressource_seq
start with 1
increment by 1
nomaxvalue;

create trigger inc_ressource_trigger
before insert on ressource
for each row
begin
select inc_ressource_seq.nextval into :new.id from dual;
end;
/

